@@ -53,6 +53,7 @@ BufferedWriteSequencer::~BufferedWriteSequencer() {
         free(mempool_.front());
         mempool_.pop();
     }
+    delete work_executor_;
 }
 
 char *BufferedWriteSequencer::RequestBuffer(size_t size) {
@@ -94,7 +95,7 @@ static ssize_t ReliableWrite(int fd, const char *buffer, const size_t size) {
 
 void BufferedWriteSequencer::WriteBuffer(char *buffer, size_t size,
                                          SeqType sequence_type,
-                                         Duration end_of_frame) {
+                                         const Duration &end_of_frame) {
     assert(buffer != nullptr);
 
     // Recover block from the raw data (our metadata starts a bit before that)
