@@ -16,15 +16,14 @@
 #ifndef KITTY_CANVAS_H
 #define KITTY_CANVAS_H
 
-#include "terminal-canvas.h"
 #include "display-options.h"
+#include "terminal-canvas.h"
 
 namespace timg {
 // Implements https://sw.kovidgoyal.net/kitty/graphics-protocol.html
 class KittyGraphicsCanvas final : public TerminalCanvas {
 public:
-    KittyGraphicsCanvas(BufferedWriteSequencer *ws,
-                        const DisplayOptions &opts);
+    KittyGraphicsCanvas(BufferedWriteSequencer *ws, const DisplayOptions &opts);
     ~KittyGraphicsCanvas() override;
 
     void Send(int x, int dy, const Framebuffer &framebuffer,
@@ -35,7 +34,7 @@ private:
 
     char *RequestBuffer(int width, int height);
 
-    char *png_buf_ = nullptr;   // Scratch buffer to encode PNG into
+    char *png_buf_       = nullptr;  // Scratch buffer to encode PNG into
     size_t png_buf_size_ = 0;
 };
 }  // namespace timg
