@@ -33,7 +33,7 @@ namespace timg {
 class STBImageSource::PreprocessedFrame {
 public:
     PreprocessedFrame(const uint8_t *image_data, int source_w, int source_h,
-                      int target_w, int target_h, Duration delay,
+                      int target_w, int target_h, const Duration &delay,
                       const DisplayOptions &opt)
         : delay_(delay), framebuffer_(target_w, target_h) {
         stbir_resize_uint8(image_data, source_w, source_h, 0,
@@ -70,6 +70,12 @@ std::string STBImageSource::FormatTitle(
 // this is not an issue.
 bool STBImageSource::LoadAndScale(const DisplayOptions &options,
                                   int frame_offset, int frame_count) {
+#ifdef WITH_TIMG_VIDEO
+    if (LooksLikeAPNG(filename())) {
+        return false;  // STB can't apng animate. Let Video do it.
+    }
+#endif
+
     FILE *img_file = stbi__fopen(filename().c_str(), "rb");
     if (!img_file) return false;
 
@@ -77,8 +83,8 @@ bool STBImageSource::LoadAndScale(const DisplayOptions &options,
     stbi__start_file(&context, img_file);
 
     int channels;
-    int target_width;
-    int target_height;
+    int target_width  = 0;
+    int target_height = 0;
 
     // There is no public API yet for accessing gif, so use some internals.
     if (stbi__gif_test(&context)) {
@@ -127,7 +133,7 @@ bool STBImageSource::LoadAndScale(const DisplayOptions &options,
     return !frames_.empty();
 }
 
-void STBImageSource::SendFrames(Duration duration, int loops,
+void STBImageSource::SendFrames(const Duration &duration, int loops,
                                 const volatile sig_atomic_t &interrupt_received,
                                 const Renderer::WriteFramebufferFun &sink) {
     int last_height         = -1;  // First image emit will not have a height.
