@@ -49,12 +49,13 @@ static void clean_up_terminal() {
 // Only one query can be going on in parallel (due to cleanup considerations)
 using ResponseFinder = std::function<const char *(const char *, size_t len)>;
 static const char *QueryTerminal(const char *query, char *const buffer,
-                                 const size_t buflen, Duration time_budget,
-                                 ResponseFinder response_found_p) {
+                                 const size_t buflen,
+                                 const Duration &time_budget,
+                                 const ResponseFinder &response_found_p) {
     // There might be pipes and redirects.
     // Let's see if we have at least one file descriptor that is connected
     // to our terminal. We can then open that terminal directly RD/WR.
-    const char *ttypath;
+    const char *ttypath = nullptr;
     for (int fd : {STDOUT_FILENO, STDERR_FILENO, STDIN_FILENO}) {
         if (isatty(fd) && (ttypath = ttyname(fd)) != nullptr) break;
     }
@@ -114,9 +115,9 @@ static const char *QueryTerminal(const char *query, char *const buffer,
     return found_pos;
 }
 
-// Read and allocate background color queried from terminal emulator.
+// Read background color queried from terminal emulator.
 // Might leak a file-descriptor when bailing out early. Accepted for brevity.
-char *QueryBackgroundColor() {
+const char *QueryBackgroundColor() {
     // The response might take a while. Typically, this should be only a
     // few milliseconds, but there can be situations over slow ssh
     // connections or very slow machines where it takes a little.
@@ -165,15 +166,15 @@ char *QueryBackgroundColor() {
 
     if (!start_color) return nullptr;
 
-    // Assemble a standard #rrggbb string into our existing buffer.
-    // NB, save, as this is not overlapping buffer areas
-    buffer[0] = '#';
-    memcpy(&buffer[1], &start_color[4], 2);
-    memcpy(&buffer[3], &start_color[9], 2);
-    memcpy(&buffer[5], &start_color[14], 2);
-    buffer[7] = '\0';
+    // Assemble a standard #rrggbb string into global static buffer.
+    static char result[8];
+    result[0] = '#';
+    memcpy(&result[1], &start_color[4], 2);
+    memcpy(&result[3], &start_color[9], 2);
+    memcpy(&result[5], &start_color[14], 2);
+    result[7] = '\0';
 
-    return strdup(buffer);
+    return result;
 }
 
 bool QueryHasKittyGraphics() {
