@@ -16,25 +16,24 @@
 #include "termutils.h"
 
 #include <strings.h>
+#include <sys/ioctl.h>
 #include <termios.h>
 #include <unistd.h>
-#include <sys/ioctl.h>
 
 namespace timg {
 // Probe all file descriptors that might be connect to tty for term size.
 TermSizeResult DetermineTermSize() {
     TermSizeResult result;
-    for (int fd : { STDOUT_FILENO, STDERR_FILENO, STDIN_FILENO }) {
+    for (int fd : {STDOUT_FILENO, STDERR_FILENO, STDIN_FILENO}) {
         struct winsize w = {};
-        if (ioctl(fd, TIOCGWINSZ, &w) != 0)
-            continue;
+        if (ioctl(fd, TIOCGWINSZ, &w) != 0) continue;
         // If we get the size of the terminals in pixels, we can determine
         // what aspect ratio the pixels have and correct if they not 1:2
         // Infer the font size if we have window pixel size available.
         // Do some basic plausibility check here.
-        if (w.ws_xpixel >= 2*w.ws_col && w.ws_ypixel >= 4*w.ws_row &&
+        if (w.ws_xpixel >= 2 * w.ws_col && w.ws_ypixel >= 4 * w.ws_row &&
             w.ws_col > 0 && w.ws_row > 0) {
-            result.font_width_px = w.ws_xpixel / w.ws_col;
+            result.font_width_px  = w.ws_xpixel / w.ws_col;
             result.font_height_px = w.ws_ypixel / w.ws_row;
         }
         result.cols = w.ws_col;
@@ -47,28 +46,30 @@ TermSizeResult DetermineTermSize() {
 bool GetBoolenEnv(const char *env_name, bool default_value) {
     const char *const value = getenv(env_name);
     if (!value) return default_value;
-    return (atoi(value) > 0
-            || strcasecmp(value, "on") == 0 || strcasecmp(value, "yes") == 0);
+    return (atoi(value) > 0 || strcasecmp(value, "on") == 0 ||
+            strcasecmp(value, "yes") == 0);
 }
 
 float GetFloatEnv(const char *env_var, float default_value) {
     const char *value = getenv(env_var);
     if (!value) return default_value;
-    char *err = nullptr;
+    char *err    = nullptr;
     float result = strtof(value, &err);
     return (*err == '\0' ? result : default_value);
 }
 
 std::string HumanReadableByteValue(int64_t byte_count) {
     float print_bytes = byte_count;
-    const char *unit = "Bytes";
+    const char *unit  = "Bytes";
     if (print_bytes > (10LL << 30)) {
         print_bytes /= (1 << 30);
         unit = "GiB";
-    } else if (print_bytes > (10 << 20)) {
+    }
+    else if (print_bytes > (10 << 20)) {
         print_bytes /= (1 << 20);
         unit = "MiB";
-    } else if (print_bytes > (10 << 10)) {
+    }
+    else if (print_bytes > (10 << 10)) {
         print_bytes /= (1 << 10);
         unit = "KiB";
     }
