@@ -75,7 +75,6 @@
 #endif
 
 using timg::Duration;
-using timg::Framebuffer;
 using timg::ImageSource;
 using timg::ITerm2GraphicsCanvas;
 using timg::KittyGraphicsCanvas;
@@ -240,6 +239,7 @@ static int usage(const char *progname, ExitCode exit_code, int width,
         "\t                unless there is more than one file to show.\n"
         "\t--frames=<num>: Only show first num frames (if looping, loop only "
         "these)\n"
+        "\t--frame-offset=<num>: Start animation/video at this frame\n"
         "\t-t<seconds>   : Stop after this time, independent of --loops or "
         "--frames\n",
         width, height, kDefaultThreadCount);
@@ -262,16 +262,17 @@ bool AppendToFileList(const std::string &filelist_file,
     std::string filename;
     for (std::string filename; std::getline(filelist_stream, filename); /**/) {
         if (filename.empty()) continue;
-        if (filename[0] != '/' && !prefix.empty()) filename = prefix + filename;
+        if (filename[0] != '/' && !prefix.empty()) filename.insert(0, prefix);
         filelist->push_back(filename);
     }
     return true;
 }
 
-static void PresentImages(LoadedImageSources &loaded_sources,
+static void PresentImages(LoadedImageSources *loaded_sources,
                           const timg::DisplayOptions &display_opts,
                           const timg::PresentationOptions &present,
-                          timg::BufferedWriteSequencer *sequencer) {
+                          timg::BufferedWriteSequencer *sequencer,
+                          bool *any_animations_seen) {
     std::unique_ptr<TerminalCanvas> canvas;
     switch (present.pixelation) {
     case Pixelation::kKittyGraphics:
@@ -318,10 +319,11 @@ static void PresentImages(LoadedImageSources &loaded_sources,
 
     // Showing them in order of files on the command line.
     bool is_first = true;
-    for (auto &source_future : loaded_sources) {
+    for (auto &source_future : *loaded_sources) {
         if (interrupt_received) break;
         std::unique_ptr<timg::ImageSource> source(source_future.get());
         if (!source) continue;
+        *any_animations_seen |= source->IsAnimationBeforeFrameLimit();
         before_image_show(is_first);
         source->SendFrames(present.duration_per_image, present.loops,
                            interrupt_received,
@@ -374,7 +376,7 @@ int main(int argc, char *argv[]) {
         OPT_CLEAR_SCREEN = 1000,
         OPT_COLOR_256,
         OPT_COMPRESS_PIXEL,
-        OPT_DEBUG_NO_FRAME_DELAY,
+        OPT_NO_FRAME_DELAY,
         OPT_FRAME_COUNT,
         OPT_FRAME_OFFSET,
         OPT_GRID,
@@ -383,47 +385,42 @@ int main(int argc, char *argv[]) {
         OPT_THREADS,
         OPT_VERBOSE,
         OPT_VERSION,
+        OPT_AUTO_CROP,
+        OPT_SCROLL,
     };
 
     // Flags with optional parameters need to be long-options, as on MacOS,
     // there is no way to have single-character options with
     static constexpr struct option long_options[] = {
-        {"auto-crop",                 optional_argument, NULL, 'T'                     },
-        {"center",                    no_argument,       NULL, 'C'                     },
-        {"clear",                     optional_argument, NULL, OPT_CLEAR_SCREEN        },
-        {"color8",                    no_argument,       NULL, OPT_COLOR_256           },
-        {"compress",                  no_argument,       NULL, OPT_COMPRESS_PIXEL      },
-        {"delta-move",                required_argument, NULL, 'd'                     },
-        {"debug-no-frame-delay",      no_argument,       NULL, OPT_DEBUG_NO_FRAME_DELAY},
-        {"experimental-frame-offset", required_argument, NULL,
-         OPT_FRAME_OFFSET                                                              },
-        {"fit-width",                 no_argument,       NULL, 'W'                     },
-        {"frames",                    required_argument, NULL, OPT_FRAME_COUNT         },
-        {"grid",                      required_argument, NULL, OPT_GRID                },
-        {"help",                      no_argument,       NULL, 'h'                     },
-        {"loops",                     optional_argument, NULL, 'c'                     },
-        {"pattern-size",              required_argument, NULL, OPT_PATTERN_SIZE        },
-        {"pixelation",                required_argument, NULL, 'p'                     },
-        {"rotate",                    required_argument, NULL, OPT_ROTATE              },
-        {"scroll",                    optional_argument, NULL, 's'                     },
-        {"threads",                   required_argument, NULL, OPT_THREADS             },
-        {"title",                     optional_argument, NULL, 'F'                     },
-        {"upscale",                   optional_argument, NULL, 'U'                     },
-        {"verbose",                   no_argument,       NULL, OPT_VERBOSE             },
-        {"version",                   no_argument,       NULL, OPT_VERSION             },
-        {0,                           0,                 0,    0                       }
+        {"auto-crop",            optional_argument, NULL, OPT_AUTO_CROP     },
+        {"center",               no_argument,       NULL, 'C'               },
+        {"clear",                optional_argument, NULL, OPT_CLEAR_SCREEN  },
+        {"color8",               no_argument,       NULL, OPT_COLOR_256     },
+        {"compress",             no_argument,       NULL, OPT_COMPRESS_PIXEL},
+        {"delta-move",           required_argument, NULL, 'd'               },
+        {"debug-no-frame-delay", no_argument,       NULL, OPT_NO_FRAME_DELAY},
+        {"frame-offset",         required_argument, NULL, OPT_FRAME_OFFSET  },
+        {"fit-width",            no_argument,       NULL, 'W'               },
+        {"frames",               required_argument, NULL, OPT_FRAME_COUNT   },
+        {"grid",                 required_argument, NULL, OPT_GRID          },
+        {"help",                 no_argument,       NULL, 'h'               },
+        {"loops",                optional_argument, NULL, 'c'               },
+        {"pattern-size",         required_argument, NULL, OPT_PATTERN_SIZE  },
+        {"pixelation",           required_argument, NULL, 'p'               },
+        {"rotate",               required_argument, NULL, OPT_ROTATE        },
+        {"scroll",               optional_argument, NULL, OPT_SCROLL        },
+        {"threads",              required_argument, NULL, OPT_THREADS       },
+        {"title",                optional_argument, NULL, 'F'               },
+        {"upscale",              optional_argument, NULL, 'U'               },
+        {"verbose",              no_argument,       NULL, OPT_VERBOSE       },
+        {"version",              no_argument,       NULL, OPT_VERSION       },
+        {0,                      0,                 0,    0                 }
     };
-    // BSD's don't have a getopt() that has the GNU extension to allow
-    // optional parameters on single-character flags, so we now only document
-    // the new --trim and --scroll but, for a while, will also silently
-    // support these old options.
-#define OLD_COMPAT_FLAGS "T::s::"
 
     int opt;
     int option_index = 0;
-    while ((opt = getopt_long(
-                argc, argv, "vg:w:t:c:f:b:B:hCFEd:UWaVIo:f:p:" OLD_COMPAT_FLAGS,
-                long_options, &option_index)) != -1) {
+    while ((opt = getopt_long(argc, argv, "vg:w:t:c:f:b:B:hCFEd:UWaVIo:f:p:",
+                              long_options, &option_index)) != -1) {
         switch (opt) {
         case 'g':
             // Parse xHEIGHT, WIDTHx, WIDTHxHEIGHT
@@ -476,7 +473,7 @@ int main(int argc, char *argv[]) {
         case 'b': bg_color = strdup(optarg); break;
         case 'B': bg_pattern_color = strdup(optarg); break;
         case OPT_PATTERN_SIZE: display_opts.pattern_size = atoi(optarg); break;
-        case 's':
+        case OPT_SCROLL:
             display_opts.scroll_animation = true;
             if (optarg != NULL) {
                 display_opts.scroll_delay = Duration::Millis(atoi(optarg));
@@ -538,9 +535,11 @@ int main(int argc, char *argv[]) {
             display_opts.upscale         = !display_opts.upscale;
             display_opts.upscale_integer = (optarg && optarg[0] == 'i');
             break;
-        case 'T':
+        case OPT_AUTO_CROP:
             display_opts.auto_crop = true;
-            if (optarg) { display_opts.crop_border = atoi(optarg); }
+            if (optarg) {
+                display_opts.crop_border = atoi(optarg);
+            }
             break;
         case 'F':
             display_opts.show_title = !display_opts.show_title;
@@ -552,7 +551,7 @@ int main(int argc, char *argv[]) {
             fprintf(stderr,
                     "timg " TIMG_VERSION
                     " <https://timg.sh/>\n"
-                    "Copyright (c) 2016..2021 Henner Zeller. "
+                    "Copyright (c) 2016..2022 Henner Zeller. "
                     "This program is free software; license GPL 2.0.\n\n");
 #ifdef WITH_TIMG_GRPAPHICSMAGICK
             fprintf(stderr, "Image decoding %s\n",
@@ -562,6 +561,15 @@ int main(int argc, char *argv[]) {
             fprintf(stderr, "Openslide %s\n",
                     timg::OpenSlideSource::VersionInfo());
 #endif
+#ifdef WITH_TIMG_JPEG
+            fprintf(stderr, "Turbo JPEG\n");
+#endif
+#ifdef WITH_TIMG_QOI
+            fprintf(stderr, "QOI Image reader\n");
+#endif
+#ifdef WITH_TIMG_STB
+            fprintf(stderr, "STB image loading fallback\n");
+#endif
 #ifdef WITH_TIMG_VIDEO
             fprintf(stderr, "Video decoding %s\n",
                     timg::VideoLoader::VersionInfo());
@@ -582,7 +590,7 @@ int main(int argc, char *argv[]) {
             }
             break;
         case 'p':
-            switch (tolower(optarg[0])) {
+            switch (tolower(optarg[0])) {  // NOLINT
             case 'h': present.pixelation = Pixelation::kHalfBlock; break;
             case 'q': present.pixelation = Pixelation::kQuarterBlock; break;
             case 'k': present.pixelation = Pixelation::kKittyGraphics; break;
@@ -594,7 +602,7 @@ int main(int argc, char *argv[]) {
             break;
         case OPT_COLOR_256: present.use_256_color = true; break;
         case OPT_VERBOSE: verbose = true; break;
-        case OPT_DEBUG_NO_FRAME_DELAY: debug_no_frame_delay = true; break;
+        case OPT_NO_FRAME_DELAY: debug_no_frame_delay = true; break;
         case 'h':
         default:
             return usage(
@@ -620,8 +628,11 @@ int main(int argc, char *argv[]) {
                      geometry_height);
     }
 
-    if ((term.font_width_px < 0 || term.font_height_px < 0) &&
-        is_pixel_direct_p(present.pixelation)) {
+    bool cell_size_warning_needed = false;
+    const bool cell_size_unknown_in_pixel_mode =
+        ((term.font_width_px < 0 || term.font_height_px < 0) &&
+         is_pixel_direct_p(present.pixelation));
+    if (cell_size_unknown_in_pixel_mode) {
         // Best effort mode if someone requests graphics protocol, but
         // we don't know cell size in pixels.
         //
@@ -631,10 +642,8 @@ int main(int argc, char *argv[]) {
         //
         // For instance, Chromium Secure Shell (hterm) extension supports
         // iTerm2 graphics, but unfortunately does not report size :(
-        fprintf(stderr,
-                "Terminal does not support pixel size query, "
-                "but graphics protocol requested.\n"
-                "Can't show animations or have columns in grid.\n");
+        // Also apparently termux (Issue #86)
+        cell_size_warning_needed = (present.grid_cols > 1);
         max_frames = 1;  // Since don't know how many cells move up next frame
         // We need a cell size to have something to scale the image into.
         display_opts.cell_x_px = 9;  // Make up some typical values.
@@ -706,7 +715,7 @@ int main(int argc, char *argv[]) {
         filelist.push_back(argv[imgarg]);
     }
 
-    if (filelist.size() <= 0) {
+    if (filelist.empty()) {
         fprintf(stderr,
                 "Expected image filename(s) on command line "
                 "or via -f\n");
@@ -737,7 +746,9 @@ int main(int argc, char *argv[]) {
                                display_opts.scroll_dx != 0;  // scroll h, fill v
 
     // Showing exactly one frame implies animation behaves as static image
-    if (max_frames == 1) { present.loops = 1; }
+    if (max_frames == 1) {
+        present.loops = 1;
+    }
 
     // If nothing is set to limit animations but we have multiple images,
     // set some sensible limit.
@@ -753,7 +764,7 @@ int main(int argc, char *argv[]) {
 
     // Asynconrous image loading (filelist.size()) and terminal query (+1)
     thread_count = (thread_count > 0 ? thread_count : kDefaultThreadCount);
-    auto pool =
+    timg::ThreadPool *const pool =
         new timg::ThreadPool(std::min(thread_count, (int)filelist.size() + 1));
 
     std::future<rgba_t> background_color_future;
@@ -798,7 +809,7 @@ int main(int argc, char *argv[]) {
             [filename, frame_offset, max_frames, do_img_loading, do_vid_loading,
              print_errors, &display_opts, &exit_code]() -> timg::ImageSource * {
             if (interrupt_received) return nullptr;
-            auto result = ImageSource::Create(
+            ImageSource *result = ImageSource::Create(
                 filename, display_opts, frame_offset, max_frames,
                 do_img_loading, do_vid_loading, print_errors);
             if (!result) exit_code = ExitCode::kImageReadError;
@@ -809,13 +820,15 @@ int main(int argc, char *argv[]) {
 
     static constexpr int kAsyncWriteQueueSize = 3;
     // Since Unicode blocks emit differences, we can't skip frames in output.
+    // TODO: should probably better ask the canvas directly instead.
     const bool buffer_allow_skipping = (display_opts.allow_frame_skipping &&
                                         is_pixel_direct_p(present.pixelation));
     timg::BufferedWriteSequencer sequencer(
         output_fd, buffer_allow_skipping, kAsyncWriteQueueSize,
         debug_no_frame_delay, interrupt_received);
     const Time start_show = Time::Now();
-    PresentImages(loaded_sources, display_opts, present, &sequencer);
+    PresentImages(&loaded_sources, display_opts, present, &sequencer,
+                  &cell_size_warning_needed);
     sequencer.Flush();
     const Time end_show = Time::Now();
 
@@ -831,8 +844,28 @@ int main(int argc, char *argv[]) {
     if (verbose) {
         fprintf(stderr, "Terminal cells: %dx%d  cell-pixels: %dx%d\n",
                 term.cols, term.rows, term.font_width_px, term.font_height_px);
+        if (term.font_width_px < 0 || term.font_height_px < 0) {
+            fprintf(stderr,
+                    "Note: Terminal does not return ws_xpixel and ws_ypixel "
+                    "in TIOCGWINSZ ioctl.\n"
+                    "\t->Aspect ratio might be off.\n"
+                    "\t->File a feature request with the terminal "
+                    "emulator program you use\n");
+        }
         fprintf(stderr, "Active Geometry: %dx%d\n", geometry_width,
                 geometry_height);
+        const rgba_t bg = display_opts.bgcolor_getter();
+        fprintf(stderr,
+                "Background color for transparency '%s', effective "
+                "RGB #%02x%02x%02x\n",
+                bg_color, bg.r, bg.g, bg.b);
+        const rgba_t checker_bg = display_opts.bg_pattern_color;
+        if (checker_bg.a == 0xff) {
+            fprintf(stderr,
+                    "\t-> Checker pattern color  '%s', "
+                    "RGB #%02x%02x%02x\n",
+                    bg_pattern_color, checker_bg.r, checker_bg.g, checker_bg.b);
+        }
         const Duration d = end_show - start_show;
         const uint64_t written_bytes =
             sequencer.bytes_total() - sequencer.bytes_skipped();
@@ -856,6 +889,15 @@ int main(int argc, char *argv[]) {
         fprintf(stderr, "\n");
     }
 
+    if (cell_size_unknown_in_pixel_mode && cell_size_warning_needed) {
+        fprintf(stderr,
+                "Terminal does not support pixel size query, "
+                "but graphics protocol requested that needs that info.\n"
+                "File an issue with your terminal implementation to implement "
+                "ws_xpixel, ws_ypixel on TIOCGWINSZ\n"
+                "Can't show animations or have columns in grid.\n");
+    }
+
     // If we were super-fast decoding and showing images that didn't need
     // transparency, the query might still be running. Wait a tiny bit so
     // that the terminal does not spill the result on the screen once we've
